@@ -4,8 +4,6 @@ use warnings;
 use strict;
 use Carp qw(cluck carp croak confess);
 use SNMP::Class::OID;
-use SNMP::Class::Value;
-use SNMP::Class::Value::MacAddress;
 use Data::Dumper;
 use Log::Log4perl qw(:easy);
 
@@ -33,4 +31,4 @@ sub get_absolute {
 	return $_[0]->{absolute_time};
 }
 
-1;
\ No newline at end of file
+1;
